Module current_executor

Module current_executor 

Provides access to the current executor in various contexts.

This module implements the executor discovery mechanism that allows async code to spawn tasks without explicitly passing an executor reference.

Functions

current_executor
Accesses the current executor using a hierarchical discovery mechanism.